@@ -160,7 +160,8 @@ class ClBuilderUpdateAction(Action):
                           Get('update.cl_update_egencache_force') == 'force'))
                       },
                      {'name': 'eix_update',
-                      'message': __("Updating the eix cache"),
+                      'message': __("Updating the eix cache for "
+                                    "{cl_builder_repository_name}"),
                       'method': 'Builder.eixUpdate(cl_builder_repository_name)',
                       'condition': (lambda Get: (
                           Get('builder.cl_builder_outdate_set') == 'on' and
